==> layoutbuilder_extras_live_update-1.0.6.tar.gz: layoutbuilder_extras_live_update/src/Form/LayoutBuilderExtrasLiveUpdateSettingsForm.php <==
<?php

namespace Drupal\layoutbuilder_extras_live_update\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form.
 */
class LayoutBuilderExtrasLiveUpdateSettingsForm extends ConfigFormBase {

  const SETTINGSNAME = 'layoutbuilder_extras_live_update.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'layoutbuilder_extras_live_update';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      self::SETTINGSNAME,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $config = $this->config(self::SETTINGSNAME);

    $form['queued_time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Queued time'),
      '#description' => $this->t('The time in seconds to wait for live updates are rendered. Only used on textfields, textarea currently.'),
      '#default_value' => $config->get('queued_time') ?? 1500,
    ];

    $form['disable_removal_submit'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable the UX improvement to remove the submit button'),
      '#description' => $this->t('Layout builder extras tries to update everthing, but in some cases like currently with EntityBrowser it is not supported. This bypasses the removal of that submit button so it still works.'),
      '#default_value' => $config->get('disable_removal_submit') ?? FALSE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->configFactory->getEditable(self::SETTINGSNAME);

    $config->set('queued_time', $form_state->getValue('queued_time', FALSE));
    $config->set('disable_removal_submit', $form_state->getValue('disable_removal_submit', FALSE));

    $config->save();
  }

}

==> layoutbuilder_extras_live_update-2.0.1.tar.gz: layoutbuilder_extras_live_update/src/Form/LayoutBuilderExtrasLiveUpdateSettingsForm.php <==
<?php

namespace Drupal\layoutbuilder_extras_live_update\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form.
 */
class LayoutBuilderExtrasLiveUpdateSettingsForm extends ConfigFormBase {

  const SETTINGSNAME = 'layoutbuilder_extras_live_update.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'layoutbuilder_extras_live_update';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      self::SETTINGSNAME,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $config = $this->config(self::SETTINGSNAME);

    $form['disable_removal_submit'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable the UX improvement to remove the submit button'),
      '#description' => $this->t('Layout builder extras tries to update everthing, but in some cases like currently with EntityBrowser it is not supported. This bypasses the removal of that submit button so it still works.'),
      '#default_value' => $config->get('disable_removal_submit') ?? TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $config = $this->configFactory->getEditable(self::SETTINGSNAME);

    $config->set('disable_removal_submit', $form_state->getValue('disable_removal_submit', TRUE));

    $config->save();
  }

}
